@@ -1,19 +1,24 @@
 """libtmux pytest plugin."""
 
+from __future__ import annotations
+
 import contextlib
+import functools
 import getpass
 import logging
 import os
-import pathlib
 import typing as t
 
 import pytest
 
 from libtmux import exc
 from libtmux.server import Server
-from libtmux.test import TEST_SESSION_PREFIX, get_test_session_name, namer
+from libtmux.test.constants import TEST_SESSION_PREFIX
+from libtmux.test.random import get_test_session_name, namer
 
 if t.TYPE_CHECKING:
+    import pathlib
+
     from libtmux.session import Session
 
 logger = logging.getLogger(__name__)
@@ -105,7 +110,7 @@ def clear_env(monkeypatch: pytest.MonkeyPatch) -> None:
             monkeypatch.delenv(k)
 
 
-@pytest.fixture(scope="function")
+@pytest.fixture
 def server(
     request: pytest.FixtureRequest,
     monkeypatch: pytest.MonkeyPatch,
@@ -136,7 +141,7 @@ def server(
 
         >>> result.assert_outcomes(passed=1)
     """
-    server = Server(socket_name="libtmux_test%s" % next(namer))
+    server = Server(socket_name=f"libtmux_test{next(namer)}")
 
     def fin() -> None:
         server.kill()
@@ -146,8 +151,8 @@ def server(
     return server
 
 
-@pytest.fixture(scope="function")
-def session_params() -> t.Dict[str, t.Any]:
+@pytest.fixture
+def session_params() -> dict[str, t.Any]:
     """Return new, temporary :class:`libtmux.Session`.
 
     >>> import pytest
@@ -184,12 +189,12 @@ def session_params() -> t.Dict[str, t.Any]:
     return {}
 
 
-@pytest.fixture(scope="function")
+@pytest.fixture
 def session(
     request: pytest.FixtureRequest,
-    session_params: t.Dict[str, t.Any],
+    session_params: dict[str, t.Any],
     server: Server,
-) -> "Session":
+) -> Session:
     """Return new, temporary :class:`libtmux.Session`.
 
     >>> from libtmux.session import Session
@@ -253,3 +258,58 @@ def session(
     assert TEST_SESSION_NAME != "tmuxp"
 
     return session
+
+
+@pytest.fixture
+def TestServer(
+    request: pytest.FixtureRequest,
+) -> type[Server]:
+    """Create a temporary tmux server that cleans up after itself.
+
+    This is similar to the server pytest fixture, but can be used outside of pytest.
+    The server will be killed when the test completes.
+
+    Returns
+    -------
+    type[Server]
+        A factory function that returns a Server with a unique socket_name
+
+    Examples
+    --------
+    >>> server = Server()  # Create server instance
+    >>> server.new_session()
+    Session($... ...)
+    >>> server.is_alive()
+    True
+    >>> # Each call creates a new server with unique socket
+    >>> server2 = Server()
+    >>> server2.socket_name != server.socket_name
+    True
+    """
+    created_sockets: list[str] = []
+
+    def on_init(server: Server) -> None:
+        """Track created servers for cleanup."""
+        created_sockets.append(server.socket_name or "default")
+
+    def socket_name_factory() -> str:
+        """Generate unique socket names."""
+        return f"libtmux_test{next(namer)}"
+
+    def fin() -> None:
+        """Kill all servers created with these sockets."""
+        for socket_name in created_sockets:
+            server = Server(socket_name=socket_name)
+            if server.is_alive():
+                server.kill()
+
+    request.addfinalizer(fin)
+
+    return t.cast(
+        "type[Server]",
+        functools.partial(
+            Server,
+            on_init=on_init,
+            socket_name_factory=socket_name_factory,
+        ),
+    )
